==> jc-1.4.0.tar.gz: gnu/java/security/x509/X509CRLSelectorImpl.h <==
// public class gnu.java.security.x509.X509CRLSelectorImpl

// class file dependencies
// @dep_class c5d2515a3de055d4 gnu_java_security_x509_X509CRLSelectorImpl
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_x509_X509CRLSelectorImpl_H_
#define _JC_gnu_java_security_x509_X509CRLSelectorImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Principal$object;
struct _jc_java_security_cert_CRL$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_refs	_jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_refs;
typedef struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_nonrefs	_jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$refs	_jc_gnu_java_security_x509_X509CRLSelectorImpl$refs;
typedef struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$nonrefs	_jc_gnu_java_security_x509_X509CRLSelectorImpl$nonrefs;
typedef struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object	_jc_gnu_java_security_x509_X509CRLSelectorImpl$object;

typedef const struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vmethods	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vmethods;
typedef const struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vtable	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vtable;
typedef const struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vtype	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vtype;

// Constructors
extern void _jc_gnu_java_security_x509_X509CRLSelectorImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *);

// Virtual methods
extern void _jc_gnu_java_security_x509_X509CRLSelectorImpl$method$addIssuerName$9da6a33e284f4b22(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_security_x509_X509CRLSelectorImpl$method$addIssuerName$cfee6fa2baca6874(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_object *);
extern void _jc_gnu_java_security_x509_X509CRLSelectorImpl$method$addIssuerName$1dbd53c377fac209(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_byte_array *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_x509_X509CRLSelectorImpl$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *);
extern struct _jc_object *_jc_gnu_java_security_x509_X509CRLSelectorImpl$method$getIssuerNames$d08100b1b6e4c03b(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *);
extern jboolean _jc_gnu_java_security_x509_X509CRLSelectorImpl$method$match$6fb8ff46fdc59150(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_java_security_cert_CRL$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$addIssuerName$9da6a33e284f4b22;
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$addIssuerName$cfee6fa2baca6874;
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$addIssuerName$1dbd53c377fac209;
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$getIssuerNames$d08100b1b6e4c03b;
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$match$6fb8ff46fdc59150;

// Virtual methods structure
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vmethods {
	void	(*addIssuerName$9da6a33e284f4b22)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_java_lang_String$object *);
	void	(*addIssuerName$cfee6fa2baca6874)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_object *);
	void	(*addIssuerName$1dbd53c377fac209)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_byte_array *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *);
	struct _jc_object	*(*getIssuerNames$d08100b1b6e4c03b)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *);
	jboolean	(*match$6fb8ff46fdc59150)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_java_security_cert_CRL$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vmethods	gnu_java_security_x509_X509CRLSelectorImpl;
};

// Vtype
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_refs {
	struct _jc_object	*issuerNames;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$refs {
    _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_refs	gnu_java_security_x509_X509CRLSelectorImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_nonrefs	gnu_java_security_x509_X509CRLSelectorImpl;
};

// Object instance structure
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object {
	_jc_gnu_java_security_x509_X509CRLSelectorImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vtype	*vtype;
	_jc_gnu_java_security_x509_X509CRLSelectorImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_X509CRLSelectorImpl$vtype _jc_gnu_java_security_x509_X509CRLSelectorImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_X509CRLSelectorImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_X509CRLSelectorImpl$class_object;

#endif	/* _JC_gnu_java_security_x509_X509CRLSelectorImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/X509CRLSelectorImpl.h <==
// public class gnu.java.security.x509.X509CRLSelectorImpl

// class file dependencies
// @dep_class c5d2515a3de055d4 gnu_java_security_x509_X509CRLSelectorImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_security_x509_X509CRLSelectorImpl_H_
#define _JC_gnu_java_security_x509_X509CRLSelectorImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Principal$object;
struct _jc_java_security_cert_CRL$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_refs	_jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_refs;
typedef struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_nonrefs	_jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$refs	_jc_gnu_java_security_x509_X509CRLSelectorImpl$refs;
typedef struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$nonrefs	_jc_gnu_java_security_x509_X509CRLSelectorImpl$nonrefs;
typedef struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object	_jc_gnu_java_security_x509_X509CRLSelectorImpl$object;

typedef const struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vmethods	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vmethods;
typedef const struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vtable	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vtable;
typedef const struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vtype	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vtype;

// Constructors
extern void _jc_gnu_java_security_x509_X509CRLSelectorImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_security_x509_X509CRLSelectorImpl$method$addIssuerName$9da6a33e284f4b22(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_x509_X509CRLSelectorImpl$method$addIssuerName$cfee6fa2baca6874(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_x509_X509CRLSelectorImpl$method$addIssuerName$1dbd53c377fac209(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_x509_X509CRLSelectorImpl$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_x509_X509CRLSelectorImpl$method$getIssuerNames$d08100b1b6e4c03b(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_security_x509_X509CRLSelectorImpl$method$match$6fb8ff46fdc59150(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_java_security_cert_CRL$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$addIssuerName$9da6a33e284f4b22;
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$addIssuerName$cfee6fa2baca6874;
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$addIssuerName$1dbd53c377fac209;
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$getIssuerNames$d08100b1b6e4c03b;
extern _jc_method _jc_gnu_java_security_x509_X509CRLSelectorImpl$method_info$match$6fb8ff46fdc59150;

// Virtual methods structure
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vmethods {
	void	(*addIssuerName$9da6a33e284f4b22)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*addIssuerName$cfee6fa2baca6874)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*addIssuerName$1dbd53c377fac209)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getIssuerNames$d08100b1b6e4c03b)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *) _JC_JCNI_ATTR;
	jboolean	(*match$6fb8ff46fdc59150)(_jc_env *, struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object *, struct _jc_java_security_cert_CRL$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vmethods	gnu_java_security_x509_X509CRLSelectorImpl;
};

// Vtype
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_refs {
	struct _jc_object	*issuerNames;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$refs {
    _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_refs	gnu_java_security_x509_X509CRLSelectorImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_X509CRLSelectorImpl$sub_nonrefs	gnu_java_security_x509_X509CRLSelectorImpl;
};

// Object instance structure
struct _jc_gnu_java_security_x509_X509CRLSelectorImpl$object {
	_jc_gnu_java_security_x509_X509CRLSelectorImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_X509CRLSelectorImpl$vtype	*vtype;
	_jc_gnu_java_security_x509_X509CRLSelectorImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_X509CRLSelectorImpl$vtype _jc_gnu_java_security_x509_X509CRLSelectorImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_X509CRLSelectorImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_X509CRLSelectorImpl$class_object;

#endif	/* _JC_gnu_java_security_x509_X509CRLSelectorImpl_H_ */
